==> otyacraftengine-forge-2.1-build1-sources.jar: dev/felnull/otyacraftengine/client/renderer/item/TestItemRenderer.java <==
package dev.felnull.otyacraftengine.client.renderer.item;

import com.mojang.blaze3d.vertex.PoseStack;
import dev.felnull.otyacraftengine.OtyacraftEngine;
import dev.felnull.otyacraftengine.client.model.SpecialModelLoader;
import dev.felnull.otyacraftengine.client.util.OERenderUtil;
import dev.felnull.otyacraftengine.item.TestItem;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.BiomeColors;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.Sheets;
import net.minecraft.client.renderer.block.model.ItemTransforms;
import net.minecraft.core.BlockPos;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.ItemStack;
import var;

public class TestItemRenderer implements BEWLItemRenderer {
    public static void init() {
        ItemRendererRegister.register(TestItem.TEST_ITEM, new TestItemRenderer());
    }

    @Override
    public void render(ItemStack stack, ItemTransforms.TransformType transformType, PoseStack poseStack, MultiBufferSource multiBufferSource, float f, int light, int overlay) {
        //   Minecraft.getInstance().getItemRenderer().renderStatic(new ItemStack(Items.APPLE), transformType, light, overlay, poseStack, multiBufferSource, 0);
        if (Minecraft.m_91087_().f_91074_ != null) {
            var pos = new BlockPos(Minecraft.m_91087_().f_91074_.m_20182_()).m_7495_();
            // var model = OERenderUtil.getBlockModel(Minecraft.getInstance().level.getBlockState(pos));
            // var model = OERenderUtil.getModel(new ModelResourceLocation(new ResourceLocation("apple"), "inventory"));
            var model = SpecialModelLoader.getInstance().getModel(new ResourceLocation(OtyacraftEngine.MODID, "block/test_model"));
            int col = BiomeColors.m_108793_(Minecraft.m_91087_().f_91073_, pos);
            OERenderUtil.renderModel(poseStack, multiBufferSource.m_6299_(Sheets.m_110790_()), model, light, overlay, col);

        }
    }
}

==> otyacraftengine-forge-2.3-build1-sources.jar: dev/felnull/otyacraftengine/client/renderer/item/TestItemRenderer.java <==
package dev.felnull.otyacraftengine.client.renderer.item;

import com.mojang.blaze3d.vertex.PoseStack;
import dev.felnull.otyacraftengine.OtyacraftEngine;
import dev.felnull.otyacraftengine.client.util.OEModelUtil;
import dev.felnull.otyacraftengine.client.util.OERenderUtil;
import dev.felnull.otyacraftengine.item.TestItem;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.Sheets;
import net.minecraft.client.renderer.block.model.ItemTransforms;
import net.minecraft.core.BlockPos;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.ItemStack;
import var;

public class TestItemRenderer implements BEWLItemRenderer {
    public static void init() {
        ItemRendererRegister.register(TestItem.TEST_ITEM, new TestItemRenderer());
    }

    @Override
    public void render(ItemStack stack, ItemTransforms.TransformType transformType, PoseStack poseStack, MultiBufferSource multiBufferSource, float f, int light, int overlay) {
        //   Minecraft.getInstance().getItemRenderer().renderStatic(new ItemStack(Items.APPLE), transformType, light, overlay, poseStack, multiBufferSource, 0);
        if (Minecraft.m_91087_().f_91074_ != null) {
            var pos = new BlockPos(Minecraft.m_91087_().f_91074_.m_20182_()).m_7495_();
            // var model = OERenderUtil.getBlockModel(Minecraft.getInstance().level.getBlockState(pos));
            // var model = OERenderUtil.getModel(new ModelResourceLocation(new ResourceLocation("apple"), "inventory"));
            var model = OEModelUtil.getModel(new ResourceLocation(OtyacraftEngine.MODID, "block/test_model"));
            //  int col = BiomeColors.getAverageGrassColor(Minecraft.getInstance().level, pos);
            OERenderUtil.renderModel(poseStack, multiBufferSource.m_6299_(Sheets.m_110790_()), model, light, overlay);
        }
    }
}
